==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/floppy/dialogs_de.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Sieht aus, als ob wir endlich da wären.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Denkst du, das ist sie?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Wie kann das alles auf eine Dreieinhalb-Zoll-Diskette passen?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Schau, sie ist viel größer als ich. Es ist eine Dreieinhalb-Meter-Diskette.")


dialogId("disk-m-velka", "font_small", "That`s better. Big plan, big disk. That makes sense.")
dialogStr("Das ist besser. Großer Plan, große Diskette. Das macht Sinn.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Denkst du, wir können sie anheben?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Das wird schwierig.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Ich denke, es ist nicht möglich. Warum sollten sie sie hier verstecken, wenn wir sie anheben können?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Ruhe, oder ich brech` dir die Kontakte ab!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Siehst du das Stahlkreuz? Das ist das Grab unser Hoffnungen.")


dialogId("disk-m-depres", "font_small", "Don`t be always so gloomy. I can`t bear it.")
dialogStr("Sei nicht immer so depressiv. Ich ertrag` das nicht.")


dialogId("disk-m-nahrat", "font_small", "Wouldn`t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Würde es nicht reichen, wenn wir den Plan von der Diskette auf unser Notebook runterladen?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Warum nicht. Hol es raus.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh, verflixt! Ich habe es zuhause gelassen.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Wollen wir es holen?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Niemals. Du findest es vielleicht lustig, aber mir tun die Flossen weh.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Viel Spaß. Ich bin neugierig, wie du das jetzt machen willst.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("Und was ist, wenn auf der Diskette gar kein Plan ist? Was, wenn sie nur hier ist, um uns durcheinanderzubringen?")


dialogId("disk-v-neverim", "font_big", "I don`t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Das glaube ich nicht. Gibt es einen anderen Gegenstand, der schwieriger herauszuholen wäre?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Was sind das für kleine Kreaturen?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Das müssen Computerviren sein.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Ihhh. Diese Monster.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn`t be happy if we pour them on their desktop.")
dialogStr("Wir müssen sehr vorsichtig sein, die nicht mit der Diskette mitzunehmen. Der Spieler wäre nicht sehr glücklich, wenn wir sie auf seinen Rechner loslassen.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Unser Ziel ist es, diese Diskette herauszuschieben.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won`t move me easily!")
dialogStr("Mich wirst Du nicht so leicht bewegen!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Das war klug!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Uuups!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Verflixt!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Aua!")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Autsch!")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Uah.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Lass mich in Ruhe!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/dialogs_de.lua <==

dialogId("disk-v-tady", "font_big", "It looks as if we finally got there.")
dialogStr("Sieht aus, als ob wir endlich da wären.")


dialogId("disk-m-tady", "font_small", "Do you think this is it?")
dialogStr("Denkst du, das ist sie?")


dialogId("disk-m-vejit", "font_small", "How could it all fit on one three and a half inch floppy?")
dialogStr("Wie kann das alles auf eine Dreieinhalb-Zoll-Diskette passen?")


dialogId("disk-v-metrova", "font_big", "Look how much bigger than me it is. It is a three and a half meter floppy.")
dialogStr("Schau, sie ist viel größer als ich. Es ist eine Dreieinhalb-Meter-Diskette.")


dialogId("disk-m-velka", "font_small", "That’s better. Big plan, big disk. That makes sense.")
dialogStr("Das ist besser. Großer Plan, große Diskette. Das macht Sinn.")


dialogId("disk-m-zvednem", "font_small", "Do you think we can lift it up?")
dialogStr("Denkst du, wir können sie anheben?")


dialogId("disk-v-tezko", "font_big", "It will be difficult.")
dialogStr("Das wird schwierig.")


dialogId("disk-v-nejde", "font_big", "I don't think it can be done. Why would they be hiding it here, if we could lift it?")
dialogStr("Ich denke, es ist nicht möglich. Warum sollten sie sie hier verstecken, wenn wir sie anheben können?")


dialogId("disk-v-ulamu", "font_big", "Shut up, or I will break off your pins!")
dialogStr("Ruhe, oder ich brech’ dir die Kontakte ab!")


dialogId("disk-v-kriz", "font_big", "Can you see that steel cross? This is the grave of our hopes.")
dialogStr("Siehst du das Stahlkreuz? Das ist das Grab unser Hoffnungen.")


dialogId("disk-m-depres", "font_small", "Don’t be always so gloomy. I can’t bear it.")
dialogStr("Sei nicht immer so depressiv. Ich ertrag’ das nicht.")


dialogId("disk-m-nahrat", "font_small", "Wouldn’t it be enough to download that plan from the floppy to our notebook?")
dialogStr("Würde es nicht reichen, wenn wir den Plan von der Diskette auf unser Notebook runterladen?")


dialogId("disk-v-mas", "font_big", "Why not. Take it out.")
dialogStr("Warum nicht. Hol es raus.")


dialogId("disk-m-sakra", "font_small", "Oh, darn! I left it at home.")
dialogStr("Oh, verflixt! Ich habe es zuhause gelassen.")


dialogId("disk-v-vratime", "font_big", "Shall we return for it?")
dialogStr("Wollen wir es holen?")


dialogId("disk-v-naano", "font_big", "Never. It may seem funny to you, but my fins are sore.")
dialogStr("Niemals. Du findest es vielleicht lustig, aber mir tun die Flossen weh.")


dialogId("disk-v-nane", "font_big", "Suit yourself. I am curious how are you going to do it now.")
dialogStr("Viel Spaß. Ich bin neugierig, wie du das jetzt machen willst.")


dialogId("disk-m-zmatlo", "font_small", "What if there is no plan on this floppy? What if it is here only to confound us?")
dialogStr("Und was ist, wenn auf der Diskette gar kein Plan ist? Was, wenn sie nur hier ist, um uns durcheinanderzubringen?")


dialogId("disk-v-neverim", "font_big", "I don’t believe that. Is there some other object that would be more difficult to get out?")
dialogStr("Das glaube ich nicht. Gibt es einen anderen Gegenstand, der schwieriger herauszuholen wäre?")


dialogId("disk-m-tvorecci", "font_small", "What kind of little creatures are those?")
dialogStr("Was sind das für kleine Kreaturen?")


dialogId("disk-v-viry", "font_big", "These must be computer viruses.")
dialogStr("Das müssen Computerviren sein.")


dialogId("disk-m-potvory", "font_small", "Yuck. Some monsters.")
dialogStr("Ihhh. Diese Monster.")


dialogId("disk-v-pozor", "font_big", "Above all, we must be careful not to take them with the disk. The player wouldn’t be happy if we pour them on their desktop.")
dialogStr("Wir müssen sehr vorsichtig sein, die nicht mit der Diskette mitzunehmen. Der Spieler wäre nicht sehr glücklich, wenn wir sie auf seinen Rechner loslassen.")


dialogId("disk-m-ukol", "font_small", "Our goal is to push out that disk.")
dialogStr("Unser Ziel ist es, diese Diskette herauszuschieben.")


dialogId("disk-x-nepohnes", "font_darkgrey", "You won’t move me easily!")
dialogStr("Mich wirst Du nicht so leicht bewegen!")


dialogId("disk-x-mazany", "font_darkgrey", "That was smart!")
dialogStr("Das war klug!")


dialogId("disk-x-jejda0", "font_darkgrey", "Ooops!")
dialogStr("Uuups!")


dialogId("disk-x-jejda1", "font_darkgrey", "Darn!")
dialogStr("Verflixt!")


dialogId("disk-x-au0", "font_darkgrey", "Oh.")
dialogStr("Aua!")


dialogId("disk-x-au1", "font_darkgrey", "Ouch.")
dialogStr("Autsch!")


dialogId("disk-x-au2", "font_darkgrey", "Yup.")
dialogStr("Uah.")


dialogId("disk-x-uzne", "font_darkgrey", "Leave me alone!")
dialogStr("Lass mich in Ruhe!")
